﻿(function (root) {
    var app = root.app;
    var dataservice = app.dataservice;
    var logger = app.logger;
    
    var personBeingEdited;
    
    var vm = {
        people: ko.observableArray([]),
        edit: function (person) {
            vm.completeEdit(personBeingEdited);
            if (person) {
                loadDevicesIfNecessary(person);
                person.isEditing(true);
                personBeingEdited = person;
            }
        },
        completeEdit: function (person) {
            if (person) {
                person.isEditing(false);               
            }
            personBeingEdited = null;
        },
        reset: function () {
            dataservice.reset(getAllPersons);
        }
    };

    getAllPersons();
    
    app.peopleViewModel = vm;
    
    /* Private functions */

    // gets all Persons asynchronously
    // returning a promise you wait for     
    function getAllPersons() {
        dataservice.getAllPersons()
            .then(processPersons)
            .fail(handleFailure);
    }
    function processPersons(persons) {
        logger.success("queryied all persons");
        vm.people([]);
        persons.forEach(function (person) {
            // Todo: add these to the personType
            if (!person.isEditing) {
                person.isEditing = ko.observable(false);
                person.FullName = ko.computed(function() {
                    return this.FirstName() + " " + this.LastName();
                }, person);
            }
            vm.people.push(person);
        });

    }

    function loadDevicesIfNecessary(person) {
        if (!person || person.areDevicesLoaded) { return; }
        person.entityAspect.loadNavigationProperty("Devices")
            .then(function () {
                logger.success("loaded devices for " + person.FullName());
                person.Devices.valueHasMutated();
                person.areDevicesLoaded = true;
            })
            .fail(handleFailure);
    }
    
    function handleFailure(error) {
        logger.error(error.message);
    }

}(window));