﻿(function (root) {
    var app = root.app;
    var logger = app.logger;

    // define Breeze namespaces
    var core = breeze.core,
        entityModel = breeze.entityModel;

    // configure Breeze for Knockout and Web API 
    core.config.setProperties({
        trackingImplementation: entityModel.entityTracking_ko,
        remoteAccessImplementation: entityModel.remoteAccess_webApi
    });

    // service name is route to our Web API controller
    var serviceName = 'api/breezydevices';

    // manager is the service gateway and cache holder
    var manager = new entityModel.EntityManager(serviceName);

    // add members to the dataservice
    var dataservice = {
        getAllPersons: getAllPersons,
        saveChanges: saveChanges,
        reset: reset
    };

    // extend the app with this dataservice
    app.dataservice = dataservice;

    /* Private functions */

    // gets all Persons asynchronously
    function getAllPersons(peopleArray) {
        var query = new entityModel.EntityQuery()
                .from("People")
                .expand("Devices")
                .orderBy("FirstName, LastName");

        logger.info("querying for all persons");
        return manager
            .executeQuery(query)
            .then(function (data) {
                processResults(data, peopleArray);
            })
            .fail(queryFailed);
    };


    function processResults(data, peopleArray) {
        var persons = data.results;
        logger.success("queried all persons");
        peopleArray.removeAll();
        persons.forEach(function (person) {
            peopleArray.push(person);
        });
    }

    function saveChanges() {
        manager.saveChanges();
        logger.success("changes saved");
    }


    function queryFailed(error) {
        logger.error("Query failed: " + error.message);
    }

    function reset(callback) {
        manager.clear();
        $.post(serviceName + '/reset', function () {
            logger.success("database reset.");
            if (callback) callback();
        });
    }

}(window));
